# Correlation between ratings of valence and arousal

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/experiments/soundgen_valid/analysis')
require(brms)
require(ggplot2)
library(ggstance)  # for horizontal violin plots
source('/home/allgoodguys/Documents/Soft_comp/R/ggplot_multiple.R') # http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/

df = read.csv('sova.csv')[, -1]

## aggregated per stimulus
a = aggregate(valence ~ sound, df, mean)
a$arousal = aggregate(arousal ~ sound, df, mean)[, 2]

mod_valAr = lm(arousal ~ valence + I(valence ^ 2), data = a)
summary(mod_valAr)
lab1 = paste('R2 =', round(summary(mod_valAr)$r.squared, 2))
plot(a$valence, a$arousal)
points(a$valence, predict(mod_valAr), type = 'p', col = 'blue', pch = 3)

a$arousal_norm = (a$arousal + 1.01)/2.02
mod_valAr_beta = brm(arousal_norm ~ valence + I(valence ^ 2), family = 'beta', data = a, iter = 2000, warmup = 500, prior = set_prior("normal(0,5)"))
summary(mod_valAr_beta)
brms::pp_check(mod_valAr_beta)

newdata = data.frame(valence = seq(min(a$valence), max(a$valence), by = .01))
fit = fitted(mod_valAr_beta, newdata = newdata, robust = TRUE)
fit = fit * 2.02 - 1.01  # convert back to -1 ... +1
colnames(fit) = c('fit', 'se', 'lwr', 'upr')
df_plot_valAr = cbind(newdata, fit)

ggplot(df_plot_valAr, aes(x = valence, y = fit, ymin = lwr, ymax = upr)) + 
  geom_line() + 
  geom_ribbon(alpha = .25) + 
  geom_point(data = a, aes(x = valence, y = arousal), inherit.aes = FALSE) +
  xlim(c(-1, 1)) + ylim(c(-1, 1)) + 
  xlab('Valence') + ylab('Arousal') +
  annotate('text', x = 0, y = 1, label = lab1) + 
  theme_bw() +
  theme(panel.grid = element_blank())

# ggsave('pix/val-ar_cor.jpg', width = 7, height = 7, units = 'cm', dpi = 300, scale = 1.5)

