# Comparing the authenticity of real/synthetic sounds with vs. without nonlinear effects

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/experiments/soundgen_valid/analysis')
library(brms)

df = read.csv('sova.csv')[, -1]

# add acoustic descriptors to the ratings from SOVA experiment
# ac = read.csv('/home/allgoodguys/Documents/Studying/Lund_PhD/experiments/soundgen_valid/stimuli/sounds_list.csv')
# ac_preds = colnames(ac)[which(colnames(ac) == 'duration') : ncol(ac)]
# idx = match(df$sound, ac$sound_mp3)
# any(is.na(idx))
# 
# for (i in ac_preds) {
#   df[, i] = ac[idx, i]
# }
# df$nonlin = factor(df$nonlin, levels = c('none', 'jump', 'biphon', 'subh', 'chaos'))
# table(ac$nonlin, ac$callType)

# model
df_aut = df[!is.na(df$authenticity), ]
df_aut$authenticity_norm = (df_aut$authenticity + 1.01)/2.02
# range(df_aut$authenticity_norm)

# mod_aut_nonlin = brm(authenticity_norm ~ type * nonlin + (1|id) + (1|sound_base), data = df_aut, family = 'beta', cores = 4, chains = 4, iter = 2000, prior = set_prior("normal(0,5)"))
# saveRDS(mod_aut_nonlin, 'models/mod_aut_nonlin.RDS')
mod_aut_nonlin = readRDS('models/mod_aut_nonlin.RDS')
# plot(mod_aut_nonlin)
# brms::pp_check(mod_aut_nonlin)
# summary(mod_aut_nonlin)

## Is there a difference between stimuli with various nonlinear effects in how their authenticity compares to the authenticity of the original prototype recordings?
newdata = expand.grid(type = levels(df_aut$type),
                      nonlin = levels(df_aut$nonlin))
fit = fitted(mod_aut_nonlin, newdata = newdata, re_formula = NA, summary = FALSE)
fit = fit * 2.02 - 1.01  # convert back to -1 ... +1
colnames(fit) = apply(newdata, 1, function(x) paste(x, collapse = '_'))
fit = as.data.frame(fit)
head(fit)

# none
soundgen:::reportCI(quantile(fit$ut_none - fit$soundgen_none, probs = c(.5, .025, .975)))

# subh
soundgen:::reportCI(quantile(fit$ut_subh - fit$soundgen_subh, probs = c(.5, .025, .975)))
subh_vs_none = (fit$ut_subh - fit$soundgen_subh) - (fit$ut_none - fit$soundgen_none)
soundgen:::reportCI(quantile(subh_vs_none, probs = c(.5, .025, .975)))

# chaos
soundgen:::reportCI(quantile(fit$ut_chaos - fit$soundgen_chaos, probs = c(.5, .025, .975)))
chaos_vs_none = (fit$ut_chaos - fit$soundgen_chaos) - (fit$ut_none - fit$soundgen_none)
soundgen:::reportCI(quantile(chaos_vs_none, probs = c(.5, .025, .975)))

# pitch jumps
soundgen:::reportCI(quantile(fit$ut_jump - fit$soundgen_jump, probs = c(.5, .025, .975)))
jump_vs_none = (fit$ut_jump - fit$soundgen_jump) - (fit$ut_none - fit$soundgen_none)
soundgen:::reportCI(quantile(jump_vs_none, probs = c(.5, .025, .975)))
