# Plotting the classification of real/synthetic sounds by emotion 

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/experiments/soundgen_valid/analysis')
library(ggplot2)
library(reshape2)

df = read.csv('sova.csv')[, -1]
ut = df[df$type == 'ut', ]
s = df[df$type == 'soundgen', ]

# s
t_s = unclass(table(s$callType, s$nameEmotion))
t_s = t(apply(t_s, 1, function(x) x / sum(x) * 100))  # transform to proportions
t_s = as.data.frame(t_s)
t_s$id = rownames(t_s)
t_s = melt(t_s, id.vars = 'id')
colnames(t_s) = c('callType', 'nameEmotion', 'count')

# capitalize first letter
t_s$nameEmotion = apply(as.matrix(t_s$nameEmotion), 1, function(x) {
  paste0(toupper(substring(x, 1, 1)), substring(x, 2))
})
t_s$callType = apply(as.matrix(t_s$callType), 1, function(x) {
  paste0(toupper(substring(x, 1, 1)), substring(x, 2))
})

t_s$nameEmotion = factor(t_s$nameEmotion, levels = c('Amusement', 'Pleasure', 'Surprise', 'Effort', 'Disgust', 'Anger', 'Fear', 'Pain', 'Sadness', 'Other'))
# 
# ggplot(t_s, aes(x = callType, y = count, group = nameEmotion, fill = nameEmotion)) +
#   geom_col(position = position_dodge(.7)) +
#   theme_bw()


# ut
t_ut = unclass(table(ut$callType, ut$nameEmotion))
t_ut = t(apply(t_ut, 1, function(x) x / sum(x) * 100))  # transform to proportions
t_ut = as.data.frame(t_ut)
t_ut$id = rownames(t_ut)
t_ut = melt(t_ut, id.vars = 'id')
colnames(t_ut) = c('callType', 'nameEmotion', 'count')

# capitalize first letter
t_ut$nameEmotion = apply(as.matrix(t_ut$nameEmotion), 1, function(x) {
  paste0(toupper(substring(x, 1, 1)), substring(x, 2))
})
t_ut$callType = apply(as.matrix(t_ut$callType), 1, function(x) {
  paste0(toupper(substring(x, 1, 1)), substring(x, 2))
})

t_ut$nameEmotion = factor(t_ut$nameEmotion, levels = c('Amusement', 'Pleasure', 'Surprise', 'Effort', 'Disgust', 'Anger', 'Fear', 'Pain', 'Sadness', 'Other'))
# 
# ggplot(t_ut, aes(x = callType, y = count, group = nameEmotion, fill = nameEmotion)) +
#   geom_col(position = position_dodge(.7)) +
#   theme_bw()

t_s$type = 'soundgen'
t_ut$type = 'human'
t_ut$count = -t_ut$count

t_mixed = rbind(t_s, t_ut)
t_mixed$callType = factor(t_mixed$callType, levels = rev(unique(t_mixed$callType)))
t_mixed$nameEm_abbr = ifelse(abs(t_mixed$count) > 12, 
                             as.character(t_mixed$nameEmotion),
                             "")
t_mixed$nameEmotion = factor(t_mixed$nameEmotion, levels = rev(levels(t_mixed$nameEmotion)))

# aggregate(count ~ callType + type, t_mixed, sum) # sum to 100% for each call type

ggplot(t_mixed, aes(x = callType, y = count, 
                    group = nameEmotion, fill = nameEmotion)) +
  geom_col(data = t_mixed[t_mixed$type == "soundgen", ], position = position_dodge(.7), width = .6) + 
  geom_col(data = t_mixed[t_mixed$type == "human", ], position = position_dodge(.7), width = .6) +
  geom_text(aes(label=nameEm_abbr), vjust=0, position = position_dodge(.7), alpha = .75, size = 4) +
  geom_hline(yintercept = 0, linetype = 2) +
  geom_vline(xintercept = seq(1.5, 6.5, 1), linetype = 2) +
  coord_flip() +
  ggtitle('Human                           Synthetic') +
  xlab('') + ylab('Proportion of answers, %') +
  scale_fill_discrete(name = '') +
  scale_y_continuous(breaks = c(-100, -50, 0, 50, 100),
                     labels = c('100', '50', '0', '50', '100'),
                     limits = c(-100, 100)) +
  theme_bw() +
  theme(plot.title = element_text(hjust = .5),
        panel.grid = element_blank()) +
  guides(fill = guide_legend(reverse = TRUE))
# ggsave(filename = 'pix/em_per_callType.jpg', width=15, height=20, units='cm', scale=1, dpi=300)
