# Miscellaneous analyses of emotion recognition

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/experiments/soundgen_valid/analysis')
library(ggplot2)
library(irr)  # for Fleiss' kappa

df = read.csv('sova.csv')[, -1]
ut = df[df$type == 'ut', ]
s = df[df$type == 'soundgen', ]

## emotion recognition
levels(df$nameEmotion)

em = data.frame(sound = levels(df$sound_base))

em_s = unclass(table(s$sound_base, s$nameEmotion))
colnames(em_s) = paste0(levels(df$nameEmotion), '_s')
em_ut = unclass(table(ut$sound_base, ut$nameEmotion))
colnames(em_ut) = paste0(levels(df$nameEmotion), '_ut')

# overall correlation of these matrices
diag(cor(em_s, em_ut))
plot(as.vector(em_s), as.vector(em_ut))
cor(as.vector(em_s), as.vector(em_ut))
chisq.test(em_s, em_ut)

d = data.frame(s = as.vector(em_s),
               ut = as.vector(em_ut))
mod1 = glm(s ~ ut, d, family = 'poisson')
mod2 = glm(s ~ ut, d, family = 'quasipoisson')
plot(mod2)
summary(mod2)
drop1(mod2, test = 'Chisq')



# for summary table
em = data.frame(sound_base = rownames(em_s))
em = cbind(em, em_s, em_ut)
rownames(em) = 1:nrow(em)
em$topName_s = levels(df$nameEmotion)[apply(em_s, 1, which.max)]
em$topName_ut = levels(df$nameEmotion)[apply(em_ut, 1, which.max)]
em$entropy_s = round(apply(em_s, 1, function(x) soundgen:::getEntropy(x, type = 'shannon', normalize = T)), 2)
em$entropy_ut = round(apply(em_ut, 1, function(x) soundgen:::getEntropy(x, type = 'shannon', normalize = T)), 2)
em$callType = df$callType[match(em$sound_base, df$sound_base)]
em$authenticity_s = round(aggregate(authenticity ~ sound_base, s, mean)[, 2], 2)
em$authenticity_ut = round(aggregate(authenticity ~ sound_base, ut, mean)[, 2], 2)
em$sureEmotion_s = round(aggregate(sureEmotion ~ sound_base, s, mean)[, 2], 2)
em$sureEmotion_ut = round(aggregate(sureEmotion ~ sound_base, ut, mean)[, 2], 2)
em$valence_s = round(aggregate(valence ~ sound_base, s, mean)[, 2], 2)
em$valence_ut = round(aggregate(valence ~ sound_base, ut, mean)[, 2], 2)
em$arousal_s = round(aggregate(arousal ~ sound_base, s, mean)[, 2], 2)
em$arousal_ut = round(aggregate(arousal ~ sound_base, ut, mean)[, 2], 2)
# write.csv(em, 'em.csv')

sum(em$authenticity_s > em$authenticity_ut)

# comparison of entropy per call type
hist(em$entropy_ut - em$entropy_s)
aggregate(entropy_s ~ callType, em, mean)
aggregate(entropy_ut ~ callType, em, mean)

library(brms)
entr = reshape2::melt(data = em, id.vars = c('sound_base', 'callType'), measure.vars = c('entropy_s', 'entropy_ut'), value.name = 'entropy')
entr$type = ifelse(entr$variable == 'entropy_s', 'synthetic', 'human')
entr$type = as.factor(entr$type)
mod_entr = brm(entropy ~ type, data = entr, cores = 4, chains = 4)
summary(mod_entr)
f = fitted(mod_entr, newdata = data.frame(type = levels(entr$type)), summary = FALSE)
quantile(f[, 2] - f[, 1], probs = c(.5, .025, .975))

mod_entr_per_call = brm(entropy ~ type * callType, data = entr, cores = 4, chains = 4)
summary(mod_entr_per_call)
brms::marginal_effects(mod_entr_per_call)


# confusion table
t = table(em$topName_ut, em$topName_s)  
t = as.data.frame(unclass(t))
t$acc = 0
for (i in 1:nrow(t)) {
  t$acc[i] = round(t[i, which(colnames(t) == rownames(t)[i])] / sum(t[i, ]) * 100)
}
t   # rows: ut, columns: soundgen

# entropy
plot(em$entropy_s, em$entropy_ut)
cor(em$entropy_s, em$entropy_ut)

# permute the dataset to estimate the level of correlation between the emotion vectors of human and synthetic sounds expected by chance
nIter = 1000

out = rep(NA, nIter)
time_start = proc.time()
for (i in 1:nIter) {
  data_main = read.csv('sova.csv')[, -1]
  data_main$sound_base = sample(data_main$sound_base) 
  data_ut = droplevels(data_main[data_main$type == 'ut', ])
  data_s = droplevels(data_main[data_main$type == 'soundgen', ])
  
  em_s = unclass(table(data_s$sound_base, data_s$nameEmotion))
  colnames(em_s) = paste0(levels(data_main$nameEmotion), '_s')
  em_ut = unclass(table(data_ut$sound_base, data_ut$nameEmotion))
  colnames(em_ut) = paste0(levels(data_main$nameEmotion), '_ut')
  
  c = data.frame(sound_base = rownames(em_s), r = NA)
  c$callType = data_main$callType[match(c$sound_base, data_main$sound_base)]
  c$sound_num = data_main$sound_num[match(c$sound_base, data_main$sound_base)]
  for (j in 1:nrow(c)) {
    ratings_s = as.numeric(em_s[j, ])
    ratings_ut = as.numeric(em_ut[j, ])
    c$r[j] = cor(ratings_s, ratings_ut) 
  }
  out[i] = mean(c$r)
  if (i %% 100 == 0) {
    soundgen:::reportTime(i, nIter = nIter, time_start = time_start)
  }
}
mean(out) # 0.16
hist(out)
qChance = quantile(out, prob = c(.5, .025, .975))
qData = data.frame(callType = c(0.4, 7.6))
qData$chance = qChance[1]
qData$ymin = qChance[2]
qData$ymax = qChance[3]

## Observed correlations between ratings on each emotion, per sound
c = data.frame(sound_base = em$sound_base, mycor = NA, myr = NA)
c$callType = df$callType[match(c$sound_base, df$sound_base)]
c$sound_num = df$sound_num[match(c$sound_base, df$sound_base)]
colnames(em)
for (i in 1:nrow(c)) {
  ratings_s = as.numeric(em[i, 2:11])
  ratings_ut = as.numeric(em[i, 12:21])
  # Pearson's r
  c$mycor[i] = cor(ratings_s, ratings_ut) 
  mod = glm(ratings_ut ~ ratings_s, family = 'poisson')
  c$myr[i] = 1 -  mod$deviance / mod$null.deviance  # pseudo-R2 for glm
}
# hist(c$mycor)
# hist(c$myr)
# summary(c$mycor)
# plot(c)
c_plot = aggregate(mycor ~ callType, c, function(x) quantile(x, probs = c(.5, .025, .975)))
c_plot = data.frame(callType = c_plot$callType,
                    fit = c_plot$mycor[, 1],
                    lwr = c_plot$mycor[, 2],
                    upr = c_plot$mycor[, 3])

mylabels = paste0(levels(c$callType))
# capitalize the first letter
mylabels = apply(as.matrix(mylabels), 1, function(x) {
  paste0(toupper(substring(x, 1, 1)), substring(x, 2))
})


ggplot(data = c, aes(x = callType, y = mycor, label = sound_num)) +
  geom_violin(fill = 'gray80', color = 'white') +
  geom_point(data = c_plot, aes(x = callType, y = fit, ymin = lwr, ymax = upr), 
             inherit.aes = FALSE, size = 3, alpha = .5) +
  # geom_errorbar(data = c_plot, aes(x = callType, y = fit, ymin = lwr, ymax = upr), inherit.aes = FALSE, width = .2) +
  geom_text(size = 3, position = position_jitter(width = .15)) + 
  scale_x_discrete(labels=mylabels) +  # % of sounds with the same top emotion for ut & soundgen
  scale_y_continuous(breaks = seq(-1, 1, by = .25)) +
  # ylim(c(-1, 1)) +
  geom_hline(yintercept=1, linetype=2) +
  geom_ribbon(data = qData, aes(x = as.numeric(callType), ymin = ymin, ymax = ymax), 
              inherit.aes = FALSE, alpha = .25) +
  annotate("text", x = 1.1, y = .2, label = "Chance level") +
  ylab("Pearson's r") +
  geom_hline(yintercept=qChance[1], linetype=2) +  # chance level
  xlab('') +
  theme_bw() +
  theme(axis.text.x = element_text(hjust = .5),
        panel.grid = element_blank())
# ggsave(filename = 'pix/recogn_per_callType.jpg', width=15, height=8, units='cm', scale=1, dpi=300) 

# decide whether cor or pseudo-R2 is more appropriate and produce a nice plot later, when there is enough data!

##
em$mycor = c$mycor
plot(em$entropy_s, em$mycor)
plot(em$entropy_ut, em$mycor)

## Does type help to predict the perceived emotion?
library(nnet)
mod1 = nnet::multinom(nameEmotion ~ sound_base + type, df[!is.na(df$nameEmotion), ])
mod2 = nnet::multinom(nameEmotion ~ sound_base, df[!is.na(df$nameEmotion), ])
anova(mod1, mod2)


## Does certainty depend on type? For which emotions / call types?
hist(df$sureEmotion)

library(lme4)
mod1 = glmer(sureEmotion ~ type + (1|id) + (1|sound_base), df, family = 'gaussian')
plot(mod1)  # check residuals when more data is available
summary(mod1)
drop1(mod1, test = 'Chisq')



## Calculating kappas
s_em = s[!is.na(s$nameEmotion), c('id', 'sound', 'nameEmotion')]

kap_s = matrix(rep(0, length(unique(s_em$sound))), ncol = 1)
rownames(kap_s) = unique(s_em$sound)
for (i in unique(s_em$id)) {
  temp = s_em[s_em$id == i, ]
  temp1 = as.character(temp$nameEmotion)
  kap_s = cbind(kap_s, temp1[match(rownames(kap_s), temp$sound)])
}
kap_s = kap_s[, -1]
irr::kappam.fleiss(kap_s)  # doesn't work because of missing values, since participants classified different sounds

# alternatively, from https://en.wikipedia.org/wiki/Fleiss%27_kappa 
kappa_fleiss = function(m) {  
  # m is matrix: rows i = classified objects (sounds), 
  #              cols j = categories, 
  #              values = how many raters put object i in category j
  pj = apply(m, 2, sum) / sum(m)  # prop. of assignments to each category
  pe = sum(pj ^ 2)
  pi = apply(m, 1, function(x) {
    n = sum(x)
    1 / (n * (n - 1)) * (sum(x ^ 2) - n)
  })
  return((mean(pi) - pe) / (1 - pe))
}
# for testing
a = matrix(c(0,0,0,0,14,
             0,2,6,4,2,
             0,0,3,5,6,
             0,3,9,2,0,
             2,2,8,1,1,
             7,7,0,0,0,
             3,2,6,3,0,
             2,5,3,2,2,
             6,5,2,1,0,
             0,2,2,3,7), 
           ncol = 5, byrow = T) 
kappa_fleiss(a)

kappa_fleiss(em_s)  # rows = sounds, cols = categories
kappa_fleiss(em_ut) 
kappa_fleiss(em_s + em_ut) 

# kappa per callType (drops as fewer stimuli are included, so it's lower for each call type than for the pooled matrix)
kappas = data.frame(callType = levels(df$callType),
                    kappa_s = NA,
                    kappa_ut = NA)
for (i in 1:nrow(kappas)) {
  s = unique(df$sound_base[df$callType == kappas$callType[i]])
  kappas$kappa_s[i] = kappa_fleiss(em_s[rownames(em_s) %in% s, ])
  kappas$kappa_ut[i] = kappa_fleiss(em_ut[rownames(em_ut) %in% s, ])
}



### How often were real vs synthetic sounds classified as "other"?
df$other = df$nameEmotion == 'other'
table(df$other, df$type)
aggregate(other ~ type, df, mean)

library(brms)
mod_other = brm(other ~ type, df, family = 'bernoulli', chains = 4, cores = 4)
summary(mod_other)

# out1 = fitted(mod_other, newdata = data.frame(type = levels(df$type)))
out2 = fitted(mod_other, newdata = data.frame(type = levels(df$type)), summary = FALSE)
quantile(out2[, 1] - out2[, 2], probs = c(.5, .025, .975))


