# Main analysis of valence-arousal-authenticity-certainty ratings; ICC

setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/experiments/soundgen_valid/analysis')
require(brms)
require(ggplot2)
library(ggstance)  # for horizontal violin plots
source('/home/allgoodguys/Documents/Soft_comp/R/ggplot_multiple.R') # http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/

df = read.csv('sova.csv')[, -1]
ut = droplevels(df[df$type == 'ut', ])
s = droplevels(df[df$type == 'soundgen', ])

mylevels = rev(c('overall', levels(df$callType)))
xlabels = paste0(rev(c('Overall', levels(df$callType))), '\n')
# capitalize the first letter
xlabels = apply(as.matrix(xlabels), 1, function(x) {
  paste0(toupper(substring(x, 1, 1)), substring(x, 2))
})


### VALENCE ###
df_val = df[!is.na(df$valence), ]
# colnames(df_val)

# hist(df_val$valence)
df_val$valence_norm = (df_val$valence + 1.01)/2.02
# range(df_val$valence_norm)

# mod_val_overall = brm(valence_norm ~ type + (1|id) + (1|sound_base), data = df_val, family = 'beta', cores = 4, chains = 4, iter = 2000, prior = set_prior("normal(0,5)"))
# saveRDS(mod_val_overall, 'models/mod_val_overall.RDS')
mod_val_overall = readRDS('models/mod_val_overall.RDS')
# plot(mod_val_overall)
# brms::pp_check(mod_val_overall)
# summary(mod_val_overall)
cov1 = fitted(mod_val_overall, 
              newdata = data.frame(type = levels(df_val$type)),
              summary = FALSE,
              re_formula = NA)
cov2 = cov1 * 2.02 - 1.01  # convert back to -1 ... +1
cov3 = cov2[, 2] - cov2[, 1]
cov4 = round(quantile(cov3, probs = c(.5, .025, .975)), 2)
contrast_overall_val = paste0(cov4[1], ' [', cov4[2], ', ', cov4[3], ']')

newdata_overall_val = expand.grid(callType = 'overall',
                              type = levels(df_val$type))
df_plot_overall_val = cbind(newdata_overall_val, fitted(mod_val_overall, newdata_overall_val, re_formula = NA, robust = TRUE))
colnames(df_plot_overall_val) = c('callType', 'type', 'fit', 'se', 'lwr', 'upr')

# mod_val = brm(valence_norm ~ callType * type + (1|id) + (1|sound_base), data = df_val, family = 'beta', cores = 4, chains = 4, iter = 2000, prior = set_prior("normal(0,5)"))
# saveRDS(mod_val, 'models/mod_val.RDS')
mod_val = readRDS('models/mod_val.RDS')
# plot(mod_val)
# brms::pp_check(mod_val)
# summary(mod_val)
# brms::marginal_effects(mod_val)

cv1 = fitted(mod_val, 
             newdata = expand.grid(callType = levels(df_val$callType),
                                   type = levels(df_val$type)),
             summary = FALSE,
             re_formula = NA)
cv2 = cv1 * 2.02 - 1.01  # convert back to -1 ... +1
contrast_val = data.frame(callType = levels(df_val$callType), cv = NA, stringsAsFactors = FALSE)
for (i in 1:7) {
  temp = round(quantile(cv2[, i + 7] - cv2[, i], probs = c(.5, .025, .975)), 2)
  contrast_val$cv[i] = paste0(temp[1], ' [', temp[2], ', ', temp[3], ']')
}
contrast_val = rbind(c('Overall', contrast_overall_val),
                     contrast_val)
contrast_val = contrast_val[nrow(contrast_val):1, ]
xlabels_val = paste0(xlabels, contrast_val$cv)

newdata_val = expand.grid(callType = levels(df_val$callType),
                          type = levels(df_val$type))
df_plot_per_type_val = cbind(newdata_val, fitted(mod_val, newdata_val, re_formula = NA, robust = TRUE))
colnames(df_plot_per_type_val) = c('callType', 'type', 'fit', 'se', 'lwr', 'upr')

df_plot_val = rbind(df_plot_overall_val, df_plot_per_type_val)
# convert back to -1 ... +1
df_plot_val[, c('fit', 'lwr', 'upr')] = df_plot_val[, c('fit', 'lwr', 'upr')] * 2.02 - 1.01  

# overlay with averages per sound
a_val_overall = aggregate(valence ~ sound + type, df_val, median)
a_val_overall$callType = 'overall'
a_val_overall = a_val_overall[, c(1, 2, 4, 3)]
a_val_per_type = aggregate(valence ~ sound + type + callType, df_val, median)
a_val = rbind(a_val_overall, a_val_per_type)
a_val$sound_num = df_val$sound_num[match(a_val$sound, df_val$sound)]
a_val$sound_num[a_val$callType == 'overall'] = ''  # to avoid cluttering the graph
df_val_plot = df_val[, c('sound', 'type', 'callType', 'valence'), ]
df_val_plot$sound_num = NA
df_val_plot = rbind(df_val_plot, a_val[a_val$callType == 'overall', ])

df_plot_val$callType = factor(df_plot_val$callType, levels = mylevels)
a_val$callType = factor(a_val$callType, levels = mylevels)
df_val_plot$callType = factor(df_val_plot$callType, levels = mylevels)
ylabels_val = c('-1\nnegative, unpleasant', '-0.5', '0', '0.5', '1\npositive, pleasant')

p_val = ggplot(df_plot_val, aes(x=callType, y=fit, ymin=lwr, ymax=upr, 
                                group=type, shape=type, fill=type)) +
  geom_violin(data=df_val_plot, aes(x=callType, y=valence, fill=type),
              inherit.aes = F, alpha=.7, col='white', position=position_dodge(.7)) +
  geom_point(size=3, position = position_dodge(.7)) +
  geom_errorbar(width=.3, size=1, position = position_dodge(.7), alpha = .6) +
  geom_text(data=a_val, aes(x=callType, y=valence, group=type, fill=type, label=sound_num), 
            # glitches unless fill is specified
            position = position_jitterdodge(dodge.width=.7, jitter.width=.3), 
            inherit.aes = F, col='black', size = 2.5) +
  geom_vline(xintercept=7.5, linetype=2) + 
  geom_hline(yintercept=0, linetype=2) +
  scale_shape_manual(name = '', labels = c('synthetic', 'human'), 
                     values = c(21, 24), guide = guide_legend(reverse=TRUE)) +
  scale_fill_manual(name = '', labels = c('synthetic', 'human'), 
                    values = c('gray40', 'gray75'), guide = guide_legend(reverse=TRUE)) +
  xlab('') + 
  ylab('Valence: how pleasant or unpleasant is the experience?') +
  scale_x_discrete(labels=xlabels_val) +
  scale_y_continuous(breaks = c(-1, -.5, 0, .5, 1), labels=ylabels_val) +
  coord_flip(expand=F) +
  ggtitle('A. Valence') +
  theme_bw() +
  theme(plot.margin = unit(c(1, 3, 0.5, 0.5), "lines"),
        plot.title = element_text(hjust = 0),
        legend.title = element_text(size = 0),
        legend.position = 'top',
        axis.ticks.y=element_blank(),
        axis.text.y = element_text(hjust = 0.5),
        panel.grid = element_blank())
# print(p_val)


### AROUSAL ###
df_ar = df[!is.na(df$arousal), ]
# colnames(df_ar)

# hist(df_ar$arousal)
df_ar$arousal_norm = (df_ar$arousal + 1.01)/2.02
# range(df_ar$arousal_norm)

# mod_ar_overall = brm(arousal_norm ~ type + (1|id) + (1|sound_base), data = df_ar, family = 'beta', cores = 4, chains = 4, iter = 2000, prior = set_prior("normal(0,5)"))
# saveRDS(mod_ar_overall, 'models/mod_ar_overall.RDS')
mod_ar_overall = readRDS('models/mod_ar_overall.RDS')
# plot(mod_ar_overall)
# brms::pp_check(mod_ar_overall)
# summary(mod_ar_overall)
coa1 = fitted(mod_ar_overall, 
              newdata = data.frame(type = levels(df_ar$type)),
              summary = FALSE,
              re_formula = NA)
coa2 = coa1 * 2.02 - 1.01  # convert back to -1 ... +1
coa3 = coa2[, 2] - coa2[, 1]
coa4 = round(quantile(coa3, probs = c(.5, .025, .975)), 2)
contrast_overall_ar = paste0(coa4[1], ' [', coa4[2], ', ', coa4[3], ']')

newdata_overall_ar = expand.grid(callType = 'overall',
                              type = levels(df_ar$type))
df_plot_overall_ar = cbind(newdata_overall_ar, fitted(mod_ar_overall, newdata_overall_ar, re_formula = NA, robust = TRUE))
colnames(df_plot_overall_ar) = c('callType', 'type', 'fit', 'se', 'lwr', 'upr')

# mod_ar = brm(arousal_norm ~ callType * type + (1|id) + (1|sound_base), data = df_ar, family = 'beta', cores = 4, chains = 4, iter = 2000, prior = set_prior("normal(0,5)"))
# saveRDS(mod_ar, 'models/mod_ar.RDS')
mod_ar = readRDS('models/mod_ar.RDS')
# plot(mod_ar)
# brms::pp_check(mod_ar)
# summary(mod_ar)
# brms::marginal_effects(mod_ar)

ca1 = fitted(mod_ar, 
             newdata = expand.grid(callType = levels(df_ar$callType),
                                   type = levels(df_ar$type)),
             summary = FALSE,
             re_formula = NA)
ca2 = ca1 * 2.02 - 1.01  # convert back to -1 ... +1
contrast_ar = data.frame(callType = levels(df_ar$callType), ca = NA, stringsAsFactors = FALSE)
for (i in 1:7) {
  temp = round(quantile(ca2[, i + 7] - ca2[, i], probs = c(.5, .025, .975)), 2)
  contrast_ar$ca[i] = paste0(temp[1], ' [', temp[2], ', ', temp[3], ']')
}
contrast_ar = rbind(c('Overall', contrast_overall_ar),
                    contrast_ar)
contrast_ar = contrast_ar[nrow(contrast_ar):1, ]
xlabels_ar = paste0(xlabels, contrast_ar$ca)

newdata_ar = expand.grid(callType = levels(df_ar$callType),
                      type = levels(df_ar$type))
df_plot_per_type_ar = cbind(newdata_ar, fitted(mod_ar, newdata_ar, re_formula = NA, robust = TRUE))
colnames(df_plot_per_type_ar) = c('callType', 'type', 'fit', 'se', 'lwr', 'upr')

df_plot_ar = rbind(df_plot_overall_ar, df_plot_per_type_ar)
# convert back to -1 ... +1
df_plot_ar[, c('fit', 'lwr', 'upr')] = df_plot_ar[, c('fit', 'lwr', 'upr')] * 2.02 - 1.01  

# overlay with averages per sound
a_ar_overall = aggregate(arousal ~ sound + type, df_ar, median)
a_ar_overall$callType = 'overall'
a_ar_overall = a_ar_overall[, c(1, 2, 4, 3)]
a_ar_per_type = aggregate(arousal ~ sound + type + callType, df_ar, median)
a_ar = rbind(a_ar_overall, a_ar_per_type)
a_ar$sound_num = df_ar$sound_num[match(a_ar$sound, df_ar$sound)]
a_ar$sound_num[a_ar$callType == 'overall'] = ''  # to avoid cluttering the graph
df_ar_plot = df_ar[, c('sound', 'type', 'callType', 'arousal'), ]
df_ar_plot$sound_num = NA
df_ar_plot = rbind(df_ar_plot, a_ar[a_ar$callType == 'overall', ])

df_plot_ar$callType = factor(df_plot_ar$callType, levels = mylevels)
a_ar$callType = factor(a_ar$callType, levels = mylevels)
df_ar_plot$callType = factor(df_ar_plot$callType, levels = mylevels)
ylabels_ar = c('-1\ncalm, low energy', '-0.5', '0', '0.5', '1\nalert, high energy')

p_ar = ggplot(df_plot_ar, aes(x=callType, y=fit, ymin=lwr, ymax=upr, 
                              group=type, shape=type, fill=type)) +
  geom_violin(data=df_ar_plot, aes(x=callType, y=arousal, fill=type), 
              inherit.aes = F, alpha=.7, col='white', position=position_dodge(.7)) +
  geom_point(size=3, position = position_dodge(.7)) +
  geom_errorbar(width=.3, size=1, position = position_dodge(.7), alpha = .6) +
  geom_text(data=a_ar, aes(x=callType, y=arousal, group=type, fill=type, label=sound_num), 
            # glitches unless fill is specified
            position = position_jitterdodge(dodge.width=.7, jitter.width=.3), 
            inherit.aes = F, col='black', size = 2.5) +
  geom_vline(xintercept=7.5, linetype=2) + 
  geom_hline(yintercept=0, linetype=2) +
  scale_shape_manual(name = '', labels = c('synthetic', 'human'), 
                     values = c(21, 24), guide = guide_legend(reverse=TRUE)) +
  scale_fill_manual(name = '', labels = c('synthetic', 'human'), 
                    values = c('gray40', 'gray75'), guide = guide_legend(reverse=TRUE)) +
  xlab('') + 
  ylab('Arousal: how high is the level of energy, alertness?') +
  scale_x_discrete(labels=xlabels_ar) +  # , position = 'top'
  scale_y_continuous(breaks = c(-1, -.5, 0, .5, 1), labels=ylabels_ar) +
  coord_flip(expand=F) +
  ggtitle('B. Arousal') +
  theme_bw() +
  theme(plot.margin = unit(c(1, 3, 0.5, 0.5), "lines"),
        plot.title = element_text(hjust = 0),
        legend.title = element_text(size = 0),
        legend.position = 'top',
        axis.ticks.y=element_blank(),
        axis.text.y = element_text(hjust = 0.5),
        panel.grid = element_blank())
# print(p_ar)

# multiplot(p_val, p_ar, cols=2)
# ggsave(plot = multiplot(p_val, p_ar, cols=2), filename = 'pix/val-ar_per_callType.jpg', width=25, height=15, units='cm', scale=1, dpi=300)  



### AUTHENTICITY ###
df_aut = df[!is.na(df$authenticity), ]
# colnames(df_aut)

# hist(df_aut$authenticity)
df_aut$authenticity_norm = (df_aut$authenticity + 1.01)/2.02
# range(df_aut$authenticity_norm)

# mod_aut_overall = brm(authenticity_norm ~ type + (1|id) + (1|sound_base), data = df_aut, family = 'beta', cores = 4, chains = 4, iter = 2000, prior = set_prior("normal(0,5)"))
# saveRDS(mod_aut_overall, 'models/mod_aut_overall.RDS')
mod_aut_overall = readRDS('models/mod_aut_overall.RDS')
# plot(mod_aut_overall)
# brms::pp_check(mod_aut_overall)
# summary(mod_aut_overall)

coaut1 = fitted(mod_aut_overall, 
                newdata = data.frame(type = levels(df_aut$type)),
                summary = FALSE,
                re_formula = NA)
coaut2 = coaut1 * 2.02 - 1.01  # convert back to -1 ... +1
coaut3 = coaut2[, 2] - coaut2[, 1]
coaut4 = round(quantile(coaut3, probs = c(.5, .025, .975)), 2)
contrast_overall_aut = paste0(coaut4[1], ' [', coaut4[2], ', ', coaut4[3], ']')

newdata_overall_aut = expand.grid(callType = 'overall',
                              type = levels(df_aut$type))
df_plot_overall_aut = cbind(newdata_overall_aut, fitted(mod_aut_overall, newdata_overall_aut, re_formula = NA, robust = TRUE))
colnames(df_plot_overall_aut) = c('callType', 'type', 'fit', 'se', 'lwr', 'upr')

# mod_aut = brm(authenticity_norm ~ callType * type + (1|id) + (1|sound_base), data = df_aut, family = 'beta', cores = 4, chains = 4, iter = 2000, prior = set_prior("normal(0,5)"))
# saveRDS(mod_aut, 'models/mod_aut.RDS')
mod_aut = readRDS('models/mod_aut.RDS')
# plot(mod_aut)
# brms::pp_check(mod_aut)
# summary(mod_aut)
# brms::marginal_effects(mod_aut)

caut1 = fitted(mod_aut, 
               newdata = expand.grid(callType = levels(df_aut$callType),
                                     type = levels(df_aut$type)),
               summary = FALSE,
               re_formula = NA)
caut2 = caut1 * 2.02 - 1.01  # convert back to -1 ... +1
contrast_aut = data.frame(callType = levels(df_aut$callType), caut = NA, stringsAsFactors = FALSE)
for (i in 1:7) {
  temp = round(quantile(caut2[, i + 7] - caut2[, i], probs = c(.5, .025, .975)), 2)
  contrast_aut$caut[i] = paste0(temp[1], ' [', temp[2], ', ', temp[3], ']')
}
contrast_aut = rbind(c('Overall', contrast_overall_aut),
                     contrast_aut)
contrast_aut = contrast_aut[nrow(contrast_aut):1, ]
xlabels_aut = paste0(xlabels, contrast_aut$caut)

newdata_aut = expand.grid(callType = levels(df_aut$callType),
                      type = levels(df_aut$type))
df_plot_per_type_aut = cbind(newdata_aut, fitted(mod_aut, newdata_aut, re_formula = NA, robust = TRUE))
colnames(df_plot_per_type_aut) = c('callType', 'type', 'fit', 'se', 'lwr', 'upr')

df_plot_aut = rbind(df_plot_overall_aut, df_plot_per_type_aut)
# convert back to -1 ... +1
df_plot_aut[, c('fit', 'lwr', 'upr')] = df_plot_aut[, c('fit', 'lwr', 'upr')] * 2.02 - 1.01  

# overlay with averages per sound
a_aut_overall = aggregate(authenticity ~ sound + type, df_aut, median)
a_aut_overall$callType = 'overall'
a_aut_overall = a_aut_overall[, c(1, 2, 4, 3)]
a_aut_per_type = aggregate(authenticity ~ sound + type + callType, df_aut, median)
a_aut = rbind(a_aut_overall, a_aut_per_type)
a_aut$sound_num = df_aut$sound_num[match(a_aut$sound, df_aut$sound)]
a_aut$sound_num[a_aut$callType == 'overall'] = ''  # to avoid cluttering the graph
df_aut_plot = df_aut[, c('sound', 'type', 'callType', 'authenticity'), ]
df_aut_plot$sound_num = NA
df_aut_plot = rbind(df_aut_plot, a_aut[a_aut$callType == 'overall', ])

df_plot_aut$callType = factor(df_plot_aut$callType, levels = mylevels)
a_aut$callType = factor(a_aut$callType, levels = mylevels)
df_aut_plot$callType = factor(df_aut_plot$callType, levels = mylevels)
ylabels_aut = c('-1\nnot at all natural', '-0.5', '0', '0.5', '1\nhighly natural')
  
p_aut = ggplot(df_plot_aut, aes(x=callType, y=fit, ymin=lwr, ymax=upr, 
                                group=type, shape=type, fill=type)) +
  geom_violin(data=df_aut_plot, aes(x=callType, y=authenticity, fill=type), 
              inherit.aes = F, alpha=.7, col='white', position=position_dodge(.7)) +
  geom_point(size=3, position = position_dodge(.7)) +
  geom_errorbar(width=.3, size=1, position = position_dodge(.7), alpha = .6) +
  geom_text(data=a_aut, aes(x=callType, y=authenticity, group=type, fill=type, label=sound_num), 
            # glitches unless fill is specified
            position = position_jitterdodge(dodge.width=.7, jitter.width=.3), 
            inherit.aes = F, col='black', size = 2.5) +
  geom_vline(xintercept=7.5, linetype=2) + 
  geom_hline(yintercept=0, linetype=2) +
  scale_shape_manual(name = '', labels = c('synthetic', 'human'), 
                     values = c(21, 24), guide = guide_legend(reverse=TRUE)) +
  scale_fill_manual(name = '', labels = c('synthetic', 'human'), 
                    values = c('gray40', 'gray75'), guide = guide_legend(reverse=TRUE)) +
  xlab('') + 
  ylab('Authenticity: is it something you might hear in real life?') +
  scale_x_discrete(labels=xlabels_aut) +
  scale_y_continuous(breaks = c(-1, -.5, 0, .5, 1), labels=ylabels_aut) +
  coord_flip(expand=F) +
  ggtitle('C. Authenticity') +
  theme_bw() +
  theme(plot.margin = unit(c(1, 3, 0.5, 0.5), "lines"),
        plot.title = element_text(hjust = 0),
        legend.title = element_text(size = 0),
        legend.position = 'top',
        axis.ticks.y=element_blank(),
        axis.text.y = element_text(hjust = 0.5),
        panel.grid = element_blank())
# print(p_aut)


### CERTAINTY ###
df_cert = df[!is.na(df$sureEmotion), ]
# colnames(df_cert)

# hist(df_cert$sureEmotion)
df_cert$sureEmotion_norm = (df_cert$sureEmotion + 1.01)/2.02
# range(df_cert$sureEmotion_norm)

# mod_cert_overall = brm(sureEmotion_norm ~ type + (1|id) + (1|sound_base), data = df_cert, family = 'beta', cores = 4, chains = 4, iter = 2000, prior = set_prior("normal(0,5)"))
# saveRDS(mod_cert_overall, 'models/mod_cert_overall.RDS')
mod_cert_overall = readRDS('models/mod_cert_overall.RDS')
# plot(mod_cert_overall)
# brms::pp_check(mod_cert_overall)
# summary(mod_cert_overall)
cocert1 = fitted(mod_cert_overall, 
                 newdata = data.frame(type = levels(df_cert$type)),
                 summary = FALSE,
                 re_formula = NA)
cocert2 = cocert1 * 2.02 - 1.01  # convert back to -1 ... +1
cocert3 = cocert2[, 2] - cocert2[, 1]
cocert4 = round(quantile(cocert3, probs = c(.5, .025, .975)), 2)
contrast_overall_cert = paste0(cocert4[1], ' [', cocert4[2], ', ', cocert4[3], ']')

newdata_overall_cert = expand.grid(callType = 'overall',
                                   type = levels(df_cert$type))
df_plot_overall_cert = cbind(newdata_overall_cert, fitted(mod_cert_overall, newdata_overall_cert, re_formula = NA, robust = TRUE))
colnames(df_plot_overall_cert) = c('callType', 'type', 'fit', 'se', 'lwr', 'upr')

# mod_cert = brm(sureEmotion_norm ~ callType * type + (1|id) + (1|sound_base), data = df_cert, family = 'beta', cores = 4, chains = 4, iter = 2000, prior = set_prior("normal(0,5)"))
# saveRDS(mod_cert, 'models/mod_cert.RDS')
mod_cert = readRDS('models/mod_cert.RDS')
# plot(mod_cert)
# brms::pp_check(mod_cert)
# summary(mod_cert)
# brms::marginal_effects(mod_cert)
ccert1 = fitted(mod_cert, 
                newdata = expand.grid(callType = levels(df_cert$callType),
                                      type = levels(df_cert$type)),
                summary = FALSE,
                re_formula = NA)
ccert2 = ccert1 * 2.02 - 1.01  # convert back to -1 ... +1
contrast_cert = data.frame(callType = levels(df_cert$callType), ccert = NA, stringsAsFactors = FALSE)
for (i in 1:7) {
  temp = round(quantile(ccert2[, i + 7] - ccert2[, i], probs = c(.5, .025, .975)), 2)
  contrast_cert$ccert[i] = paste0(temp[1], ' [', temp[2], ', ', temp[3], ']')
}
contrast_cert = rbind(c('Overall', contrast_overall_cert),
                      contrast_cert)
contrast_cert = contrast_cert[nrow(contrast_cert):1, ]
xlabels_cert = paste0(xlabels, contrast_cert$ccert)

newdata_cert = expand.grid(callType = levels(df_cert$callType),
                           type = levels(df_cert$type))
df_plot_per_type_cert = cbind(newdata_cert, fitted(mod_cert, newdata_cert, re_formula = NA, robust = TRUE))
colnames(df_plot_per_type_cert) = c('callType', 'type', 'fit', 'se', 'lwr', 'upr')

df_plot_cert = rbind(df_plot_overall_cert, df_plot_per_type_cert)
# convert back to -1 ... +1
df_plot_cert[, c('fit', 'lwr', 'upr')] = df_plot_cert[, c('fit', 'lwr', 'upr')] * 2.02 - 1.01  

# overlay with averages per sound
a_cert_overall = aggregate(sureEmotion ~ sound + type, df_cert, median)
a_cert_overall$callType = 'overall'
a_cert_overall = a_cert_overall[, c(1, 2, 4, 3)]
a_cert_per_type = aggregate(sureEmotion ~ sound + type + callType, df_cert, median)
a_cert = rbind(a_cert_overall, a_cert_per_type)
a_cert$sound_num = df_cert$sound_num[match(a_cert$sound, df_cert$sound)]
a_cert$sound_num[a_cert$callType == 'overall'] = ''  # to avoid cluttering the graph
df_cert_plot = df_cert[, c('sound', 'type', 'callType', 'sureEmotion'), ]
df_cert_plot$sound_num = NA
df_cert_plot = rbind(df_cert_plot, a_cert[a_cert$callType == 'overall', ])

df_plot_cert$callType = factor(df_plot_cert$callType, levels = mylevels)
a_cert$callType = factor(a_cert$callType, levels = mylevels)
df_cert_plot$callType = factor(df_cert_plot$callType, levels = mylevels)
ylabels_cert = c('-1\nno idea', '-0.5', '0', '0.5', '1\nsure')

p_cert = ggplot(df_plot_cert, aes(x=callType, y=fit, ymin=lwr, ymax=upr, 
                                  group=type, shape=type, fill=type)) +
  geom_violin(data=df_cert_plot, aes(x=callType, y=sureEmotion, fill=type), 
              inherit.aes = F, alpha=.7, col='white', position=position_dodge(.7)) +
  geom_point(size=3, position = position_dodge(.7)) +
  geom_errorbar(width=.3, size=1, position = position_dodge(.7), alpha = .6) +
  geom_text(data=a_cert, aes(x=callType, y=sureEmotion, group=type, 
                             fill=type, label=sound_num), 
            # glitches unless fill is specified
            position = position_jitterdodge(dodge.width=.7, jitter.width=.3), 
            inherit.aes = F, col='black', size = 2.5) +
  geom_vline(xintercept=7.5, linetype=2) + 
  geom_hline(yintercept=0, linetype=2) +
  scale_shape_manual(name = '', labels = c('synthetic', 'human'), 
                     values = c(21, 24), guide = guide_legend(reverse=TRUE)) +
  scale_fill_manual(name = '', labels = c('synthetic', 'human'), 
                    values = c('gray40', 'gray75'), guide = guide_legend(reverse=TRUE)) +
  xlab('') + 
  ylab('Certainty: how sure are you about the emotion?') +
  scale_x_discrete(labels=xlabels_cert) +  # , position = 'top'
  scale_y_continuous(breaks = c(-1, -.5, 0, .5, 1), labels=ylabels_cert) +
  coord_flip(expand=F) +
  ggtitle('D. Certainty') +
  theme_bw() +
  theme(plot.margin = unit(c(1, 3, 0.5, 0.5), "lines"),
        plot.title = element_text(hjust = 0),
        legend.title = element_text(size = 0),
        legend.position = 'top',
        axis.ticks.y=element_blank(),
        axis.text.y = element_text(hjust = 0.5),
        panel.grid = element_blank())
# print(p_cert)


# multiplot(p_aut, p_cert, cols=2)
# ggsave(plot = multiplot(p_aut, p_cert, cols=2), filename = 'pix/aut-cert_per_callType.jpg', width=25, height=15, units='cm', scale=1, dpi=300)  


# multiplot(p_val, p_ar, p_aut, p_cert, cols=2)
ggsave(plot = multiplot(p_val, p_aut, p_ar, p_cert, cols=2), filename = 'pix/all-ratings_per_callType.jpg', width=25, height=30, units='cm', scale=1, dpi=300)  

# 
# # to get the names of sounds with particular numbers, eg laugh 27-30:
# unique(df$sound_base[df$sound_num %in% c(27:30)])


### Reliability of ratings within type (ut / s) and across types
library(ICC)
ICC::ICCest(x = sound, y = valence, data = df_val)$ICC
ICC::ICCest(x = sound, y = valence, data = df_val[df_val$type == 'soundgen', ])$ICC
ICC::ICCest(x = sound, y = valence, data = df_val[df_val$type == 'ut', ])$ICC
boxplot(valence ~ sound, df_val)
boxplot(valence ~ sound, s)
boxplot(valence ~ sound, ut)

ICC::ICCest(x = sound, y = arousal, data = df_ar)$ICC
ICC::ICCest(x = sound, y = arousal, data = df_ar[df_ar$type == 'soundgen', ])$ICC
ICC::ICCest(x = sound, y = arousal, data = df_ar[df_ar$type == 'ut', ])$ICC

ICC::ICCest(x = sound, y = authenticity, data = df_aut)$ICC
ICC::ICCest(x = sound, y = authenticity, data = df_aut[df_aut$type == 'soundgen', ])$ICC
ICC::ICCest(x = sound, y = authenticity, data = df_aut[df_aut$type == 'ut', ])$ICC
